==> ruby-foreman_0.85.0.orig.tar.gz: foreman-0.85.0/README.md <==
# Foreman

[![Build Status](https://travis-ci.org/ddollar/foreman.svg?branch=master)](https://travis-ci.org/ddollar/foreman)
[![Code Climate](https://codeclimate.com/github/ddollar/foreman.svg)](https://codeclimate.com/github/ddollar/foreman)
[![Inline docs](http://inch-ci.org/github/ddollar/foreman.svg?branch=master)](http://inch-ci.org/github/ddollar/foreman)

Manage Procfile-based applications

## Installation

    $ gem install foreman

Ruby users should take care *not* to install foreman in their project's `Gemfile`.

## Getting Started

* http://blog.daviddollar.org/2011/05/06/introducing-foreman.html

## Supported Ruby versions

See [.travis.yml](.travis.yml) for a list of Ruby versions against which Foreman is tested.

## Documentation

* [man page](http://ddollar.github.io/foreman/)
* [wiki](https://github.com/ddollar/foreman/wiki)
* [changelog](https://github.com/ddollar/foreman/blob/master/Changelog.md)

## Ports

* [forego](https://github.com/ddollar/forego) - Go
* [node-foreman](https://github.com/strongloop/node-foreman) - Node.js
* [gaffer](https://github.com/jingweno/gaffer) - Java/JVM
* [goreman](https://github.com/mattn/goreman) - Go
* [honcho](https://github.com/nickstenning/honcho) - python
* [proclet](https://github.com/kazeburo/Proclet) - Perl
* [shoreman](https://github.com/chrismytton/shoreman) - shell
* [crank](https://github.com/arktisklada/crank) - Crystal
* [houseman](https://github.com/fujimura/houseman) - Haskell
* [spm](https://github.com/bytegust/spm) - Go

## Authors

#### Created and maintained by
David Dollar

#### Patches contributed by
[Contributor List](https://github.com/ddollar/foreman/contributors)

## License

Foreman is licensed under the MIT license.

See LICENSE for the full license text.

==> ruby-foreman_0.87.2.orig.tar.gz: foreman-0.87.2/README.md <==
# Foreman

[![Build Status](https://travis-ci.org/ddollar/foreman.svg?branch=master)](https://travis-ci.org/ddollar/foreman)
[![Code Climate](https://codeclimate.com/github/ddollar/foreman.svg)](https://codeclimate.com/github/ddollar/foreman)
[![Inline docs](http://inch-ci.org/github/ddollar/foreman.svg?branch=master)](http://inch-ci.org/github/ddollar/foreman)

Manage Procfile-based applications

## Installation

    $ gem install foreman

Ruby users should take care *not* to install foreman in their project's `Gemfile`. See this [wiki article](https://github.com/ddollar/foreman/wiki/Don't-Bundle-Foreman) for more details.

## Getting Started

* http://blog.daviddollar.org/2011/05/06/introducing-foreman.html

## Supported Ruby versions

See [.travis.yml](.travis.yml) for a list of Ruby versions against which Foreman is tested.

## Documentation

* [man page](http://ddollar.github.io/foreman/)
* [wiki](https://github.com/ddollar/foreman/wiki)
* [changelog](https://github.com/ddollar/foreman/blob/master/Changelog.md)

## Ports

* [forego](https://github.com/ddollar/forego) - Go
* [node-foreman](https://github.com/strongloop/node-foreman) - Node.js
* [gaffer](https://github.com/jingweno/gaffer) - Java/JVM
* [goreman](https://github.com/mattn/goreman) - Go
* [honcho](https://github.com/nickstenning/honcho) - python
* [proclet](https://github.com/kazeburo/Proclet) - Perl
* [shoreman](https://github.com/chrismytton/shoreman) - shell
* [crank](https://github.com/arktisklada/crank) - Crystal
* [houseman](https://github.com/fujimura/houseman) - Haskell
* [spm](https://github.com/bytegust/spm) - Go

## Authors

#### Created and maintained by
David Dollar

#### Patches contributed by
[Contributor List](https://github.com/ddollar/foreman/contributors)

## License

Foreman is licensed under the MIT license.

See LICENSE for the full license text.
